"""
Author: James Londal
Copyright: Copyright 2019, Picopie Ltd
License: GNU AFFERO GENERAL PUBLIC LICENSE
Version: 1.0.0
Maintainer: James Londal
"""

#converts SuperScout file to DataFrame
from pyrugga.match import Match

__version__ = "1.4"
